#
#
#
#  Shooter Set-Up Plugin for Dreambox E2
#  Support: www.dreambox-tools.info
#  (c)2008 Coded by Vali 
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.



from Screens.Screen import Screen
from Components.ActionMap import ActionMap, NumberActionMap
from Components.PluginComponent import plugins
from Components.PluginList import *
from Components.Label import Label
from Screens.MessageBox import MessageBox
from Plugins.Plugin import PluginDescriptor
from Tools.LoadPixmap import LoadPixmap
import os



def main(session, **kwargs):
	session.open(Shooter_PluginSelector)

	
	
def Plugins(**kwargs):
	return \
		[PluginDescriptor(name="Shooter Setup", description="Configure the Shooter functions", icon="shooter.png", where = PluginDescriptor.WHERE_PLUGINMENU, fnc=main)]



class Shooter_PluginSelector(Screen):
	skin = """
		<screen name="Shooter_PluginSelector" position="160,95" size="400,405" title="Shooter plugin selector">
			<ePixmap pixmap="/usr/lib/enigma2/python/Plugins/Extensions/ShooterSetup/red-big.png" position="0,0" size="200,40" alphatest="on" />
			<ePixmap pixmap="/usr/lib/enigma2/python/Plugins/Extensions/ShooterSetup/green-big.png" position="200,0" size="200,40" alphatest="on" />
			<widget name="red" position="0,0" zPosition="1" size="200,40" font="Regular;20" halign="center" valign="center" backgroundColor="#9f1313" transparent="1" />
			<widget name="green" position="200,0" zPosition="1" size="200,40" font="Regular;20" halign="center" valign="center" backgroundColor="#1f771f" transparent="1" />
			<widget name="list" position="0,45" size="400,355" scrollbarMode="showOnDemand" />
		</screen>"""

	def __init__(self, session):
		self.skin = Shooter_PluginSelector.skin
		self.session = session
		Screen.__init__(self, session)
		self["red"] = Label(_("Save as SHOOT"))
		self["green"] = Label(_("Activate Help"))
		self.list = []
		self["list"] = PluginList(self.list)
		self.updateList()
		self["actions"] = ActionMap(["WizardActions", "ColorActions"],
		{
			"ok": self.close,
			"back": self.close,
			"red": self.activiereShooter,
			"green": self.activiereHelp
		})
		self.onExecBegin.append(self.checkWarnings)


	def checkWarnings(self):
		if len(plugins.warnings):
			text = _("Some plugins are not available:\n")
			for (pluginname, error) in plugins.warnings:
				text += _("%s (%s)\n") % (pluginname, error)
			plugins.resetWarnings()
			self.session.open(MessageBox, text = text, type = MessageBox.TYPE_WARNING)


	def save(self):
		plugin2save = self["list"].l.getCurrentSelection()[0]
		name2save = plugin2save.name
		try:
			f = open("/etc/shooter.name", "w")
			f.write(name2save+"/ ready2shooting")
			f.close()
		except:
			info = self.session.open(MessageBox, text = 'Error by writing the Shooter file.', type = MessageBox.TYPE_WARNING)
			info.setTitle(_('Error'))


	def updateList(self):
		self.list = [ ]
		self.pluginlist = plugins.getPlugins(PluginDescriptor.WHERE_PLUGINMENU)
		for plugin in self.pluginlist:
			self.list.append(PluginEntryComponent(plugin))
		self["list"].l.setList(self.list)


	def activiereShooter(self):
		self.save()
		self.close(0)


	def activiereHelp(self):
		try:
			os.system('rm -f /etc/shooter.name')
		except:
			info = self.session.open(MessageBox, text = 'Error by activating Help.', type = MessageBox.TYPE_WARNING)
			info.setTitle(_('Error'))

